pub struct ChatCompletionChunkChoice {
pub index: u32,
pub delta: ChatCompletionChunkDelta,
pub finish_reason: Option<String>,
}Expand description
Represents a single choice in a streaming chat completion response.
Fields
index: u32The index of the choice in the list of choices.
delta: ChatCompletionChunkDeltaA delta payload with the content that has changed since the last chunk.
finish_reason: Option<String>The reason the model stopped generating tokens.