pub struct CompatWarning {
pub code: String,
pub message: String,
pub path: Option<String>,
}Expand description
Non-blocking compatibility warning emitted by Rainy in envelope mode.
Fields
code: StringWarning code identifier.
message: StringHuman-readable warning message.
path: Option<String>JSON path to the field that triggered the warning.