pub struct CreditInfo {
pub current_credits: f64,
pub estimated_cost: f64,
pub credits_after_request: f64,
pub reset_date: String,
}Expand description
Represents information about credit usage for a request.
Fields
current_credits: f64The number of credits available before the request.
estimated_cost: f64The estimated number of credits that the request will cost.
credits_after_request: f64The estimated number of credits remaining after the request.
reset_date: StringThe date when the credit balance is next scheduled to be reset.