pub struct RateLimiter { /* private fields */ }๐Deprecated:
Use the governor-based rate limiting in RainyClient instead
A simple rate limiter.
This rate limiter is deprecated and should not be used in new code.
The RainyClient now uses a more robust, feature-flagged rate limiting mechanism
based on the governor crate.
Implementations
Sourceimpl RateLimiter
impl RateLimiter
Sourcepub fn new(requests_per_minute: u32) -> Self
pub fn new(requests_per_minute: u32) -> Self
Creates a new RateLimiter.
Arguments
requests_per_minute- The maximum number of requests allowed per minute.
Sourcepub async fn wait_if_needed(&mut self) -> Result<()>
pub async fn wait_if_needed(&mut self) -> Result<()>
Pauses execution if the rate limit has been exceeded.
This method will asynchronously wait until the next request can be sent without violating the rate limit.