Defines error types and result aliases for the SDK.
Structs
- ApiError
Details - Detailed information about an API error.
- ApiError
Response - The structure of a standard error response from the Rainy API.
Enums
- Rainy
Error - The comprehensive error type for all operations within the Rainy SDK.
Type Aliases
- Result
- A convenience type alias for
Result<T, RainyError>.